@@ -4,7 +4,7 @@
 
 library(civis)
 
-job <- scripts_post_custom(from_template_id = 9925)
+job <- scripts_post_custom(from_template_id = 13448)
 run <- scripts_post_custom_runs(job$id)
 await(scripts_get_custom_runs, id = job$id, run_id = run$id)
 spec_id <- scripts_list_custom_runs_outputs(job$id, run$id)[[1]]$objectId
@@ -16,8 +16,6 @@ Sys.setenv("CIVIS_API_KEY" = "")
 
 api_spec <- jsonlite::fromJSON(fn, simplifyVector = FALSE)
 
-# To pass R CMD CHECK, this has to be an 'R Data file' (rda) produced by save.
-save(api_spec, file = "../R/sysdata.rda")
 client_str <- civis:::generate_client(api_spec)
 civis:::write_client(client_str, FILENAME = paste0("../", civis:::FILENAME))
 devtools::document()
